'''
area type table module
'''

import os

from lxml import etree

from errors import AreaTypeTableCorruptError, AreaTypeTableNotFoundError

class AreaTypeTable(object):
    def __init__(self, filename):
        if not os.path.isfile(filename):
            raise AreaTypeTableNotFoundError('XML input file not found')
        parser = etree.XMLParser(remove_blank_text=True)
        self.tree = etree.parse(filename, parser)
        self.root = self.tree.getroot()
        # generate and save a list of all area types in file
        self.area_types = [node.get('id') for node in self.root.iter('entry')]
        # save version number and date
        version_tag = self.root.find('version_number')
        date_tag = self.root.find('date')
        if version_tag is None or date_tag is None:
            raise AreaTypeTableCorruptError('version_number and/or date tags missing')
        self.version = version_tag.text
        self.date = date_tag.text

    def get_version(self):
        return self.version

    def get_date(self):
        return self.date

    def exists(self, area_type):
        return area_type in self.area_types
