'''
tests for area_type_table module
'''

import os

from nose import tools as nt

from CFchecker.area_type_table import AreaTypeTable
from CFchecker.errors import AreaTypeTableNotFoundError

_tempdir = '/tmp/'
_moduledir = os.path.dirname(__file__)

class AreaTypeTable_test:
    test_area_type_table = os.path.join(_moduledir, 'test_area_type_table.xml')
    nonexistent_area_type_table = os.path.join(_tempdir, 'tests_nonexistent_area_type_table.xml')

    @classmethod
    def setup_class(cls):
        if os.path.exists(cls.nonexistent_area_type_table): os.remove(cls.nonexistent_area_type_table)
        if not os.path.exists(cls.test_area_type_table):
            raise Exception('area type table test input file %s not found' % cls.test_area_type_table)

    def test_init_ok(self):
        '''AreaTypeTable: init with valid table file'''
        area_type_table = AreaTypeTable(self.test_area_type_table)
        nt.assert_equal(set(area_type_table.area_types), set(['bare_ground', 'all_area_types', 'sea', 'sea_ice',
                                                              'clear_sky', 'cloud', 'floating_ice', 'ice_free_sea',
                                                              'lake_ice_or_sea_ice', 'land', 'land_ice', 'snow', 'vegetation']))
    def test_init_nofile(self):
        '''AreaTypeTable: init with non-existing file'''
        nt.assert_raises(AreaTypeTableNotFoundError, AreaTypeTable, self.nonexistent_area_type_table)
    def test_get_version(self):
        '''AreaTypeTable: get_version()'''
        area_type_table = AreaTypeTable(self.test_area_type_table)
        nt.assert_equals(area_type_table.get_version(), '1')
    def test_get_date(self):
        '''AreaTypeTable: get_last_modified()'''
        area_type_table = AreaTypeTable(self.test_area_type_table)
        nt.assert_equals(area_type_table.get_date(), '5 December 2008')
    def test_exists_ok(self):
        '''AreaTypeTable: exists()'''
        area_type_table = AreaTypeTable(self.test_area_type_table)
        area_types = ['bare_ground', 'all_area_types', 'lake_ice_or_sea_ice', 'floating_ice']
        for area_type in area_types:
            nt.assert_true(area_type_table.exists(area_type))
        area_types = ['foo', 'bar', 'baz']
        for area_type in area_types:
            nt.assert_false(area_type_table.exists(area_type))
