'''
nose unit tests for CFchecker.cf14
'''
import os

from nose import tools as nt

import CFchecker
from CFchecker.errors import CFCheckerError

from cf10_test import _moduledir

from CFchecker.cf14 import CF14Tests
import cf13_test
import helpers

class CF14Tests_test(cf13_test.CF13Tests_test):
    '''
    test 7.3 changed
    '''
    test_class = CF14Tests

    test_area_type_table = os.path.join(_moduledir, 'test_area_type_table.xml')

    @classmethod
    def setup_class(cls):
        cf13_test.CF13Tests_test.setup_class()
        helpers.amend_faulty_ncfile_cf14(os.path.join(cls.tempdir, cls.faulty_file))
        helpers.amend_good_ncfile_cf14(os.path.join(cls.tempdir, cls.good_file))

    def test_init(self):
        '''CF14Tests: init input file handling'''
        # test init with list of tests to run
        cftest = self.test_class(name_table_file=self.test_name_table,
                                 area_type_file=self.test_area_type_table, tests_to_run=['2.1','2.2','2.3'])
        nt.assert_true(set(['name_table', 'area_type_table', 'tests_to_run']).issubset(set(dir(cftest))))
        nt.assert_equals(cftest.tests_to_run, ['_test_2_1', '_test_2_2', '_test_2_3'])

    def test_run(self):
        '''CF14Tests: run()'''
        cftest = self.test_class(name_table_file=self.test_name_table, tests_to_run=['2.1'])

        # test log entries with empty file and only one test selected(should only be INIT messages)
        cftest.run(os.path.join(self.tempdir, self.empty_file))
        log = cftest.get_messagelog().get_raw_log()
        nt.assert_equals(log, [('INFO', 'INIT', 'running CFchecker version %s' % (CFchecker.__version__,)),
                               ('INFO', 'INIT', 'checking compliance with convention %s' % self.test_class.cf_convention),
                               ('INFO', 'INIT', 'will only run the following tests: 2.1'),
                               ('INFO', 'INIT', 'using standard name table version: 12, ' \
                                                'last modified: 2009-07-06T12:05:02Z'),
                               ('INFO', 'INIT', 'using area type table version: 2, date: 10 July 2013'),
                              ])
        # test if nonexistent file causes error
        nt.assert_raises(CFCheckerError, cftest.run, self.file_noexist)

    def test_7_3_check(self):
        '''CF14Tests: test 7.3'''
        msgs = { self.faulty_file: [   ('ERROR', '7.3', 'no_std_name: cell_methods dimension "lon" has to be a dimension of '
                                                        'the associated variable, a valid standard name, the word "area" or an '
                                                        'associated scalar coordinate variable'),
                                       ('ERROR', '7.3', 'no_std_name: cell_methods dimension "lat" has to be a dimension of '
                                                        'the associated variable, a valid standard name, the word "area" or an '
                                                        'associated scalar coordinate variable'),
                                       ('WARNING', '7.3', 'no_std_name: variable dimension "lev2" refers to vertical dimension, '
                                                          'it should have a cell_methods entry covering this dimension'),
                                       ('WARNING', '7.3', 'no_std_name: variable dimension "time" refers to time dimension, it '
                                                          'should have a cell_methods entry covering this dimension'),
                                       ('ERROR', '7.3', '_spam_data: cell_methods has to be of type string'),
                                       ('ERROR', '7.3', 'casetest: cell_methods could not be parsed: first piece does not end '
                                                        'with ":" (\'not\')'),
                                       ('ERROR', '7.3', 'CaseTest: dimension name "latitude" is only allowed to occur once in '
                                                        'cell_methods string'),
                                       ('ERROR', '7.3', 'double_axis: in cell_methods comment: interval unit "degrees_X" not '
                                                        'recognized'),
                                       ('ERROR', '7.3', 'double_axis: in cell_methods comment: interval length "one" not a '
                                                        'valid number'),
                                       ('ERROR', '7.3', 'wrong_dim_order: cell_methods comments could not be parsed: malformed '
                                                        'interval clause found'),
                                       ('WARNING', '7.3', 'wrong_dim_order: variable dimension "time" refers to time dimension, it '
                                                          'should have a cell_methods entry covering this dimension'),
                                       ('WARNING', '7.3', 'wrong_dim_order: coordinate/scalar variable "lev" named by cell_methods '
                                                          'should have either bounds or climatology attribute'),
                                       ('WARNING', '7.3', 'double_dependency: variable dimension "lat" refers to horizontal dimension, '
                                                          'it should have a cell_methods entry covering this dimension'),
                                       ('WARNING', '7.3', 'double_dependency: variable dimension "lon" refers to horizontal dimension, '
                                                          'it should have a cell_methods entry covering this dimension'),
                                       ('ERROR', '7.3', 'double_dependency: cell_methods where type1 "sea_foo" must be a valid variable '
                                                        'name or area type.'),
                                       ('ERROR', '7.3', 'double_dependency: cell_methods where type2 "bla_foo" must be a valid variable '
                                                        'name or area type.'),
                                       ('ERROR', '7.3', 'T: cell_methods attribute given but no content found'),
                                       ],
                 self.good_file: [],
                }
        self.check_runner(msgs)
